You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@manifoldcf.apache.org by kw...@apache.org on 2013/04/25 02:18:21 UTC

svn commit: r1471790 - /manifoldcf/trunk/tests/webcrawler/src/test/java/org/apache/manifoldcf/webcrawler_tests/ThrottlingTester.java

Author: kwright
Date: Thu Apr 25 00:18:21 2013
New Revision: 1471790

URL: http://svn.apache.org/r1471790
Log:
Fix the processed documents test.

Modified:
    manifoldcf/trunk/tests/webcrawler/src/test/java/org/apache/manifoldcf/webcrawler_tests/ThrottlingTester.java

Modified: manifoldcf/trunk/tests/webcrawler/src/test/java/org/apache/manifoldcf/webcrawler_tests/ThrottlingTester.java
URL: http://svn.apache.org/viewvc/manifoldcf/trunk/tests/webcrawler/src/test/java/org/apache/manifoldcf/webcrawler_tests/ThrottlingTester.java?rev=1471790&r1=1471789&r2=1471790&view=diff
==============================================================================
--- manifoldcf/trunk/tests/webcrawler/src/test/java/org/apache/manifoldcf/webcrawler_tests/ThrottlingTester.java (original)
+++ manifoldcf/trunk/tests/webcrawler/src/test/java/org/apache/manifoldcf/webcrawler_tests/ThrottlingTester.java Thu Apr 25 00:18:21 2013
@@ -136,18 +136,9 @@ public class ThrottlingTester
 
     // Check to be sure we actually processed the right number of documents.
     JobStatus status = jobManager.getStatus(job.getID());
-    // Four levels deep from 10 site seeds: Each site seed has 1 + 10 + 100 + 1000 = 1111 documents, so 100 has 111100
-    if (status.getDocumentsProcessed() != 111100)
-    {
-      System.err.println("Sleeping for database inspection");
-      while (true)
-      {
-        if (1 < 0)
-          break;
-        Thread.sleep(10000L);
-      }
+    // Four levels deep from 100 site seeds: Each site seed has 1 + 10 + 100 + 1000 = 1111 documents, so 100 has 111100 total, and 11100 processed
+    if (status.getDocumentsProcessed() != 11100)
       throw new ManifoldCFException("Wrong number of documents processed - expected 111100, saw "+new Long(status.getDocumentsProcessed()).toString());
-    }
     
     // Now, delete the job.
     jobManager.deleteJob(job.getID());